@@ -84,7 +84,7 @@
 #define KDESU_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KDESU_NO_DEPRECATED
-#  define KDESU_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56e00
+#  define KDESU_DISABLE_DEPRECATED_BEFORE_AND_AT 0x57300
 #endif
 #ifdef KDESU_NO_DEPRECATED_WARNINGS
 #  define KDESU_DEPRECATED_WARNINGS_SINCE 0
@@ -94,7 +94,7 @@
 #  ifdef KDESU_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KDESU_DEPRECATED_WARNINGS_SINCE KDESU_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KDESU_DEPRECATED_WARNINGS_SINCE 0x56e00
+#    define KDESU_DEPRECATED_WARNINGS_SINCE 0x57300
 #  endif
 #endif
 
